@@ -3,13 +3,22 @@ from functools import wraps
 
 from django.utils.decorators import available_attrs
 
-from rest_framework_extensions.utils import get_cache
+
 from rest_framework_extensions.settings import extensions_api_settings
-from rest_framework_extensions.compat import six
+from django.utils import six
+
+
+def get_cache(alias):
+    from django.core.cache import caches
+    return caches[alias]
 
 
 class CacheResponse(object):
-    def __init__(self, timeout=None, key_func=None, cache=None):
+    def __init__(self,
+                 timeout=None,
+                 key_func=None,
+                 cache=None,
+                 cache_errors=None):
         if timeout is None:
             self.timeout = extensions_api_settings.DEFAULT_CACHE_RESPONSE_TIMEOUT
         else:
@@ -20,6 +29,11 @@ class CacheResponse(object):
         else:
             self.key_func = key_func
 
+        if cache_errors is None:
+            self.cache_errors = extensions_api_settings.DEFAULT_CACHE_ERRORS
+        else:
+            self.cache_errors = cache_errors
+
         self.cache = get_cache(cache or extensions_api_settings.DEFAULT_USE_CACHE)
 
     def __call__(self, func):
@@ -53,9 +67,13 @@ class CacheResponse(object):
             response = view_method(view_instance, request, *args, **kwargs)
             response = view_instance.finalize_response(request, response, *args, **kwargs)
             response.render()  # should be rendered, before picklining while storing to cache
-            self.cache.set(key, response, self.timeout)
+
+            if not response.status_code >= 400 or self.cache_errors:
+                self.cache.set(key, response, self.timeout)
+
         if not hasattr(response, '_closable_objects'):
             response._closable_objects = []
+
         return response
 
     def calculate_key(self,
@@ -77,4 +95,4 @@ class CacheResponse(object):
         )
 
 
-cache_response = CacheResponse
\ No newline at end of file
+cache_response = CacheResponse
