@@ -1,7 +1,15 @@
 # -*- coding: utf-8 -*-
-from django.utils.encoding import force_text
 from django.utils.translation import get_language
 from django.db.models.query import EmptyQuerySet
+from django.db.models.sql.datastructures import EmptyResultSet
+
+from django.utils.encoding import force_text
+
+
+class AllArgsMixin(object):
+
+    def __init__(self, params='*'):
+        super(AllArgsMixin, self).__init__(params)
 
 
 class KeyBitBase(object):
@@ -24,18 +32,25 @@ class KeyBitDictBase(KeyBitBase):
 
     def get_data(self, params, view_instance, view_method, request, args, kwargs):
         data = {}
-        source_dict = self.get_source_dict(
-            params=params,
-            view_instance=view_instance,
-            view_method=view_method,
-            request=request,
-            args=args,
-            kwargs=kwargs
-        )
-        for key in params:
-            value = source_dict.get(self.prepare_key_for_value_retrieving(key))
-            if value is not None:
-                data[self.prepare_key_for_value_assignment(key)] = force_text(value)
+
+        if params is not None:
+            source_dict = self.get_source_dict(
+                params=params,
+                view_instance=view_instance,
+                view_method=view_method,
+                request=request,
+                args=args,
+                kwargs=kwargs
+            )
+
+            if params == '*':
+                params = source_dict.keys()
+
+            for key in params:
+                value = source_dict.get(self.prepare_key_for_value_retrieving(key))
+                if value is not None:
+                    data[self.prepare_key_for_value_assignment(key)] = force_text(value)
+
         return data
 
     def get_source_dict(self, params, view_instance, view_method, request, args, kwargs):
@@ -137,7 +152,7 @@ class RequestMetaKeyBit(KeyBitDictBase):
         return request.META
 
 
-class QueryParamsKeyBit(KeyBitDictBase):
+class QueryParamsKeyBit(AllArgsMixin, KeyBitDictBase):
     """
     Return example:
         {'part': 'Londo', 'callback': 'jquery_callback'}
@@ -156,32 +171,59 @@ class PaginationKeyBit(QueryParamsKeyBit):
     """
     def get_data(self, **kwargs):
         kwargs['params'] = []
-        if hasattr(kwargs['view_instance'], 'page_kwarg'):
-            kwargs['params'].append(kwargs['view_instance'].page_kwarg)
-        if hasattr(kwargs['view_instance'], 'paginate_by_param'):
-            kwargs['params'].append(kwargs['view_instance'].paginate_by_param)
+        if hasattr(kwargs['view_instance'], 'paginator'):
+            if hasattr(kwargs['view_instance'].paginator, 'page_query_param'):
+                kwargs['params'].append(
+                    kwargs['view_instance'].paginator.page_query_param)
+            if hasattr(kwargs['view_instance'].paginator,
+                       'page_size_query_param'):
+                kwargs['params'].append(
+                    kwargs['view_instance'].paginator.page_size_query_param)
         return super(PaginationKeyBit, self).get_data(**kwargs)
 
 
-class ListSqlQueryKeyBit(KeyBitBase):
-    def get_data(self, params, view_instance, view_method, request, args, kwargs):
-        queryset = view_instance.filter_queryset(view_instance.get_queryset())
+class SqlQueryKeyBitBase(KeyBitBase):
+    def _get_queryset_query_string(self, queryset):
         if isinstance(queryset, EmptyQuerySet):
             return None
         else:
-            return force_text(queryset.query.__str__())
+            try:
+                return force_text(queryset.query.__str__())
+            except EmptyResultSet:
+                return None
 
 
-class RetrieveSqlQueryKeyBit(KeyBitBase):
+class ListSqlQueryKeyBit(SqlQueryKeyBitBase):
+    def get_data(self, params, view_instance, view_method, request, args, kwargs):
+        queryset = view_instance.filter_queryset(view_instance.get_queryset())
+        return self._get_queryset_query_string(queryset)
+
+
+class RetrieveSqlQueryKeyBit(SqlQueryKeyBitBase):
     def get_data(self, params, view_instance, view_method, request, args, kwargs):
         lookup_value = view_instance.kwargs[view_instance.lookup_field]
         try:
             queryset = view_instance.filter_queryset(view_instance.get_queryset()).filter(
                 **{view_instance.lookup_field: lookup_value}
             )
-            if isinstance(queryset, EmptyQuerySet):
-                return None
-            else:
-                return force_text(queryset.query.__str__())
         except ValueError:
-            return None
\ No newline at end of file
+            return None
+        else:
+            return self._get_queryset_query_string(queryset)
+
+
+class ArgsKeyBit(AllArgsMixin, KeyBitBase):
+
+    def get_data(self, params, view_instance, view_method, request, args, kwargs):
+        if params == '*':
+            return args
+        elif params is not None:
+            return [args[i] for i in params]
+        else:
+            return []
+
+
+class KwargsKeyBit(AllArgsMixin, KeyBitDictBase):
+
+    def get_source_dict(self, params, view_instance, view_method, request, args, kwargs):
+        return kwargs
