@@ -75,10 +75,10 @@ class KeyConstructor(object):
         )
 
     def prepare_key(self, key_dict):
-        return hashlib.sha256(json.dumps(key_dict, sort_keys=True).encode('utf-8')).hexdigest()
+        return hashlib.md5(json.dumps(key_dict, sort_keys=True).encode('utf-8')).hexdigest()
 
     def get_data_from_bits(self, **kwargs):
-        result_dict = {}    
+        result_dict = {}
         for bit_name, bit_instance in self.bits.items():
             if bit_name in self.params:
                 params = self.params[bit_name]
@@ -103,4 +103,4 @@ class DefaultObjectKeyConstructor(DefaultKeyConstructor):
 
 class DefaultListKeyConstructor(DefaultKeyConstructor):
     list_sql_query = bits.ListSqlQueryKeyBit()
-    pagination = bits.PaginationKeyBit()
\ No newline at end of file
+    pagination = bits.PaginationKeyBit()
